@@ -18,7 +18,7 @@
 */
 
 /* sprite.h
- *
+ * 
  * $Id$
  *
  * Notice: This header file contains declarations of functions and types that
@@ -32,8 +32,7 @@
 #include "ming.h"
 #include "character.h"
 #include "scalinggrid.h"
-/* Commented by Yixuan Qiu */
-/* #include "action.h" */
+#include "action.h"
 
 /* movie clip extends sprite, so we need a public definition */
 
